==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/extensions/DoneableHorizontalPodAutoscaler.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Function;

public class DoneableHorizontalPodAutoscaler extends HorizontalPodAutoscalerFluentImpl<DoneableHorizontalPodAutoscaler> implements Doneable<HorizontalPodAutoscaler>,HorizontalPodAutoscalerFluent<DoneableHorizontalPodAutoscaler>{


    private final HorizontalPodAutoscalerBuilder builder;    private final Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function;
    public DoneableHorizontalPodAutoscaler ( Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function){
    this.builder=new HorizontalPodAutoscalerBuilder(this);this.function=function;
}
    public DoneableHorizontalPodAutoscaler ( HorizontalPodAutoscaler item,  Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function){
    this.builder=new HorizontalPodAutoscalerBuilder(this);this.function=function;
}
    public DoneableHorizontalPodAutoscaler ( HorizontalPodAutoscaler item){
    this.builder=new HorizontalPodAutoscalerBuilder(this, item);this.function=new Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler>() {
    public HorizontalPodAutoscaler apply(HorizontalPodAutoscaler item) {
        return item;
    }
}
;
}

    public HorizontalPodAutoscaler done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/kubernetes/api/model/extensions/DoneableHorizontalPodAutoscaler.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableHorizontalPodAutoscaler extends HorizontalPodAutoscalerFluentImpl<DoneableHorizontalPodAutoscaler> implements Doneable<HorizontalPodAutoscaler>, HorizontalPodAutoscalerFluent<DoneableHorizontalPodAutoscaler>{


    private final HorizontalPodAutoscalerBuilder builder;    private final Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function;
    public DoneableHorizontalPodAutoscaler ( Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function){
    this.builder=new HorizontalPodAutoscalerBuilder(this);this.function=function;
}
    public DoneableHorizontalPodAutoscaler ( HorizontalPodAutoscaler item,  Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler> function){
    this.builder=new HorizontalPodAutoscalerBuilder(this, item);this.function=function;
}
    public DoneableHorizontalPodAutoscaler ( HorizontalPodAutoscaler item){
    this.builder=new HorizontalPodAutoscalerBuilder(this, item);this.function=new Function<HorizontalPodAutoscaler, HorizontalPodAutoscaler>() {
    public HorizontalPodAutoscaler apply(HorizontalPodAutoscaler item) {
        return item;
    }
}
;
}

    public HorizontalPodAutoscaler done(){
     return function.apply(builder.build());
}


}
